@@ -1,13 +1,6 @@
 import unittest
-try:
-    import SPARQLWrapper
-except ImportError:
-    from nose.exc import SkipTest
-    raise SkipTest("SPARQLWrapper not installed")
-
 from rdflib.graph import Graph
 
-
 class TestSPARQLStoreGraphCore(unittest.TestCase):
 
     store_name = 'SPARQLStore'
@@ -27,5 +20,6 @@ class TestSPARQLStoreGraphCore(unittest.TestCase):
     def test(self):
         print("Done")
 
+
 if __name__ == '__main__':
     unittest.main()
