@@ -3,54 +3,55 @@ import rdflib
 import re
 
 from nose import SkipTest
-from rdflib.py3compat import b
+from six import b
 
 TRIPLE = (rdflib.URIRef("http://example.com/s"),
           rdflib.RDFS.label,
           rdflib.Literal("example 1"))
 
+
 class TestTrig(unittest.TestCase):
 
     def testEmpty(self):
-        g=rdflib.Graph()
-        s=g.serialize(format='trig')
+        g = rdflib.Graph()
+        s = g.serialize(format='trig')
         self.assertTrue(s is not None)
 
     def testRepeatTriples(self):
-        g=rdflib.ConjunctiveGraph()
-        g.get_context('urn:a').add(( rdflib.URIRef('urn:1'),
-                                     rdflib.URIRef('urn:2'),
-                                     rdflib.URIRef('urn:3') ))
+        g = rdflib.ConjunctiveGraph()
+        g.get_context('urn:a').add((rdflib.URIRef('urn:1'),
+                                    rdflib.URIRef('urn:2'),
+                                    rdflib.URIRef('urn:3')))
 
-        g.get_context('urn:b').add(( rdflib.URIRef('urn:1'),
-                                     rdflib.URIRef('urn:2'),
-                                     rdflib.URIRef('urn:3') ))
+        g.get_context('urn:b').add((rdflib.URIRef('urn:1'),
+                                    rdflib.URIRef('urn:2'),
+                                    rdflib.URIRef('urn:3')))
 
-        self.assertEqual(len(g.get_context('urn:a')),1)
-        self.assertEqual(len(g.get_context('urn:b')),1)
+        self.assertEqual(len(g.get_context('urn:a')), 1)
+        self.assertEqual(len(g.get_context('urn:b')), 1)
 
-        s=g.serialize(format='trig')
-        self.assertTrue(b('{}') not in s) # no empty graphs!
+        s = g.serialize(format='trig')
+        self.assertTrue(b('{}') not in s)  # no empty graphs!
 
     def testSameSubject(self):
-        g=rdflib.ConjunctiveGraph()
-        g.get_context('urn:a').add(( rdflib.URIRef('urn:1'),
-                                     rdflib.URIRef('urn:p1'),
-                                     rdflib.URIRef('urn:o1') ))
+        g = rdflib.ConjunctiveGraph()
+        g.get_context('urn:a').add((rdflib.URIRef('urn:1'),
+                                    rdflib.URIRef('urn:p1'),
+                                    rdflib.URIRef('urn:o1')))
 
-        g.get_context('urn:b').add(( rdflib.URIRef('urn:1'),
-                                     rdflib.URIRef('urn:p2'),
-                                     rdflib.URIRef('urn:o2') ))
+        g.get_context('urn:b').add((rdflib.URIRef('urn:1'),
+                                    rdflib.URIRef('urn:p2'),
+                                    rdflib.URIRef('urn:o2')))
 
-        self.assertEqual(len(g.get_context('urn:a')),1)
-        self.assertEqual(len(g.get_context('urn:b')),1)
+        self.assertEqual(len(g.get_context('urn:a')), 1)
+        self.assertEqual(len(g.get_context('urn:b')), 1)
 
-        s=g.serialize(format='trig')
+        s = g.serialize(format='trig')
 
         self.assertEqual(len(re.findall(b("p1"), s)), 1)
         self.assertEqual(len(re.findall(b("p2"), s)), 1)
 
-        self.assertTrue(b('{}') not in s) # no empty graphs!
+        self.assertTrue(b('{}') not in s)  # no empty graphs!
 
     def testRememberNamespace(self):
         g = rdflib.ConjunctiveGraph()
