@@ -1,7 +1,8 @@
 import unittest
 
-from rdflib import URIRef, BNode, Literal, RDFS
-from rdflib.Graph import Graph
+from rdflib.term import BNode, Literal
+from rdflib.namespace import RDFS
+from rdflib.graph import Graph
 
 
 class GraphTest(unittest.TestCase):
@@ -29,7 +30,6 @@ class GraphTest(unittest.TestCase):
         for s, p, o in self.store:
             pass
 
+
 if __name__ == "__main__":
     unittest.main()
-
-
